==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTextAreaUI.h <==
// public class javax.swing.plaf.basic.BasicTextAreaUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class 27bcdace371120b javax_swing_plaf_basic_BasicTextAreaUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextUI

#include "javax/swing/plaf/basic/BasicTextUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextAreaUI_H_
#define _JC_javax_swing_plaf_basic_BasicTextAreaUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$refs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object	_jc_javax_swing_plaf_basic_BasicTextAreaUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextAreaUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *);

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicTextAreaUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicTextAreaUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextAreaUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextAreaUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicTextAreaUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods	javax_swing_plaf_basic_BasicTextAreaUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$refs {
    _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs	javax_swing_plaf_basic_BasicTextAreaUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextAreaUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object {
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype _jc_javax_swing_plaf_basic_BasicTextAreaUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextAreaUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextAreaUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextAreaUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTextAreaUI.h <==
// public class javax.swing.plaf.basic.BasicTextAreaUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class 27bcdace371120b javax_swing_plaf_basic_BasicTextAreaUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextUI

#include "javax/swing/plaf/basic/BasicTextUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextAreaUI_H_
#define _JC_javax_swing_plaf_basic_BasicTextAreaUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$refs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object	_jc_javax_swing_plaf_basic_BasicTextAreaUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextAreaUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicTextAreaUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicTextAreaUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextAreaUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextAreaUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicTextAreaUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vmethods	javax_swing_plaf_basic_BasicTextAreaUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$refs {
    _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_refs	javax_swing_plaf_basic_BasicTextAreaUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextAreaUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextAreaUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextAreaUI$object {
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextAreaUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextAreaUI$vtype _jc_javax_swing_plaf_basic_BasicTextAreaUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextAreaUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextAreaUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextAreaUI_H_ */
